django\_sorcery.formsets package
================================

.. automodule:: django_sorcery.formsets
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   django_sorcery.formsets.base
   django_sorcery.formsets.inline
